@@ -231,7 +231,7 @@ class League(BaseLeague):
         power_rank = power_points(dominance_matrix, teams_sorted, week)
         return power_rank
 
-    def free_agents(self, week: int=None, size: int=50, position: str=None) -> List[Player]:
+    def free_agents(self, week: int=None, size: int=50, position: str=None, position_id: int=None) -> List[Player]:
         '''Returns a List of Free Agents for a Given Week\n
         Should only be used with most recent season'''
 
@@ -243,6 +243,9 @@ class League(BaseLeague):
         slot_filter = []
         if position and position in POSITION_MAP:
             slot_filter = [POSITION_MAP[position]]
+        if position_id:
+            slot_filter.append(position_id)
+
         
         params = {
             'view': 'kona_player_info',
@@ -259,11 +262,12 @@ class League(BaseLeague):
 
         return [BoxPlayer(player, pro_schedule, positional_rankings, week) for player in players]
 
-    def player_info(self, name: str):
+    def player_info(self, name: str = None, playerId: int = None):
         ''' Returns Player class if name found '''
-        playerId = self.player_map.get(name)
 
-        if playerId is None:
+        if name:
+            playerId = self.player_map.get(name)
+        if playerId is None or isinstance(playerId, str):
             return None
         params = { 'view': 'kona_playercard' }
         filters = {'players':{'filterIds':{'value':[playerId]}, 'filterStatsForTopScoringPeriodIds':{'value':16}}}
@@ -271,6 +275,6 @@ class League(BaseLeague):
 
         data = self.espn_request.league_get(params=params, headers=headers)
         
-        player = data['players'][0]
-        return Player(player)
+        if len(data['players']) > 0:
+            return Player(data['players'][0])
 
